| GET.elabftw.bycaption | R Documentation |
This function fetches experimental data from the online labbook eLabFTW as a data frame. The html table that will be returned as data frame must be marked with a caption. The first cell of the first row of the table will be interpreted as the caption. The caption is removed from the final data frame.
GET.elabftw.bycaption(
experiment.id,
caption = "Messdaten",
dec = ",",
header = F,
api.key = Sys.getenv("READ_ELABFTW_TOKEN"),
url = Sys.getenv("ELABFTW_API_URL"),
outputHTTP = F
)
experiment.id |
The eLabFTW id of the experiment that will be fetched. The id can be found in the url of the experiment. |
caption |
A string identifying the table. The caption must be placed in the first cell of the first row of the table. |
dec |
The decimal separator used in the table. The default is the German number notation with a comma instead of a period! |
header |
Is the first line of the table the column names or data? If true, the first row is no data. |
api.key |
The eLabFT API-key. See the eLabFTW documentation for details. The default settings retrieve this value from the enviourmental variable READ_ELABFTW_TOKEN. This variable can be set in the ~/.Renviron file. |
url |
The url to the eLabFTW API. See the eLabFTW documentation for details. The default settings retrieve this value from the enviourmental variable ELABFTW_API_URL. This variable can be set in the ~/.Renviron file. |
outputHTTP |
Boolean value. If FALSE only the selected tables will be returned. If TRUE the selected tables and the original http response received from the API will be returned. The http response contains meta information needed by other parsing functions. |
Keep in mind: Tables that have a caption can't be parsed by GET.elabftw.byselector().
A list of data frames with the content of the selected html tables from the eLabFTW online labbook. If outputHTTP is set TRUE the return value is a list containing the list of all data frames created from the selected html tables and the original http response received from the API.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.